Dependencies
============

The only requirement is Python >=3.6. The following dependencies will also be installed:

- [`xarray`](http://xarray.pydata.org/en/stable/) 
- [`dask`](https://docs.dask.org/en/latest/install.html)
- [`scipy`](https://scipy.org/scipylib/)
- [`scikit-image`](https://scikit-image.org/)

